"""
Lightweight Python Build Tool
"""

import pkgutil

from ._nb import add_env, dump, main, pushd, task, zipdir

__path__ = pkgutil.extend_path(__path__, __name__)

__all__ = ["task", "main", "zipdir", "add_env", "dump", "dumps", "pushd", "print_out", "print_err"]



__version__ = "1.0.0"
__license__ = "MIT License"
__website__ = "https://github.com/navio-online/navio-builder/"
__download_url__ = "https://github.com/navio-online/navio-builder/archive/" "{}.tar.gz".format(__version__)
